Module: CAL
- Defined in:
- lib/remind/calendar.rb
Overview
Icalendar wrapper.
Allows injection of ics calender events from either a remote server or file. Meant to provide the backbone event source for local reminders.
Defined Under Namespace
Class Method Summary collapse
-
.from_file(f) ⇒ Object
Load Calendar Event Collection from file
f. -
.from_url(u) ⇒ Object
Load Calendar Event Collection from url
u.